#!/bin/sh

command0="radar24-json-adapter"
ftco_max="100"

instance=""
log_file=""

if [ "$1" = "-l" ] ; then
    if [ -n "$2" ] ; then
        log_file=$2
    else
        log_file="instance_d_log.txt"
    fi
else
    if [ "$1" = "-i" ] ; then
        if [ -n "$2" ] ; then
            instance=$2
        else
            echo "Error: instance key is passed but instance is not defined. Exiting..."
            exit
        fi
    fi

    if [ "$3" = "-l" ] ; then
        if [ -n "$4" ] ; then
            log_file=$4
        else
            if [ -n "$instance" ] ; then
                log_file="instance_${instance}_log.txt"
            else
                log_file="instance_d_log.txt"
            fi
        fi
    fi
fi

if [ -n "$instance" ] ; then
    ins_test=`expr $instance + 1 - 1 2>/dev/null`
    if [ "$instance" != "$ins_test" ] ; then
        echo "Error: instance should be integer. Exiting..."
        exit        
    fi
fi

cfg_file=""
cnt_file=""
nst_file=""
pid_file=""

if [ -n "$instance" ] ; then
    ./finish.sh -i $instance
    pid_file=".instance_$instance.pid"
    cnt_file=".instance_${instance}_stopped.counter"
    cfg_file="instance_${instance}_config.json"
    nst_file="nostart_$instance"
else
    ./finish.sh
    pid_file=".instance_d.pid"
    cnt_file=".instance_d_stopped.counter"
    cfg_file="default_config.json"
    nst_file="nostart_d"
fi

echo "Config file is '$cfg_file'."

if [ -n "$log_file" ] ; then
    echo "Logging requested, log file is '$log_file'."
fi

arg_cmd0="-c $cfg_file -m"

echo "0" > $cnt_file

while [ 1 -eq 1 ] ; do
    if [ -f "nostart" -o -f "$nst_file" ] ; then
        echo "Nostart flag found. Exiting..."
        exit
    fi

    if [ -n "$log_file" ] ; then
        echo "Executing './$command0 $arg_cmd0 1>>$log_file 2>&1 &'..."
        ./$command0 $arg_cmd0 1>>$log_file 2>&1 &
    else
        echo "Executing './$command0 $arg_cmd0 1>/dev/null 2>&1 &'..."
        ./$command0 $arg_cmd0 1>/dev/null 2>&1 &
    fi

    pid=$!
    echo "Pid is $pid."
    echo "$pid" > $pid_file
    echo "Working (infinite loop until terminated)..."
    wait $pid

    echo "Process finished with error, terminated or crashed."
    cnt=`cat $cnt_file`
    cnt=`expr $cnt + 1 2>/dev/null`
    if [ -z "$cnt" ] ; then
        cnt="1"
    fi
    echo "Finish/terminate/crash occurrence count is $cnt."
    echo "$cnt" > $cnt_file
    
    echo "Removing pid info file..."
    rm -f $pid_file

    if [ $cnt -gt $ftco_max ] ; then
        echo "Finish/terminate/crash occurrence count has exceeded it's limit. Exiting..."
        exit
    fi
done

